
#include "aboutdialog.h"

#include <qlabel.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include "images.h"
#include <qlayout.h>

#include "version.h"

AboutDialog::AboutDialog(QWidget * parent, const char * name, bool modal, WFlags f)
	: QDialog(parent, name, modal, f) 
{
	setCaption( tr("About SMPlayer") );

	logo = new QLabel(this);
	logo->setPixmap( Images::icon("logo", 64) );

	intro = new QLabel(this);
#if QT_VERSION >= 0x040000
	intro->setWordWrap(true);
#endif

	foot = new QLabel(this),
	credits = new QTextEdit(this);
	credits->setReadOnly(true);
	ok_button = new QPushButton( tr("&Ok"), this );
	connect( ok_button, SIGNAL(clicked()), this, SLOT(accept()) );

	QVBoxLayout * l1 = new QVBoxLayout(0, 4, 2);
	l1->addWidget( intro );
	l1->addWidget( credits );
	l1->addWidget( foot );

	QSpacerItem * sp3 = new QSpacerItem( 10, 10, QSizePolicy::Expanding, QSizePolicy::Expanding );
	QVBoxLayout * l5 = new QVBoxLayout(0, 4, 2);
	l5->addWidget( logo );
	l5->addItem( sp3 );
	

	QHBoxLayout * l2 = new QHBoxLayout(0, 4, 2);
	l2->addLayout( l5 );
	l2->addLayout( l1 );

	QSpacerItem * sp1 = new QSpacerItem( 10, 10, QSizePolicy::Expanding, QSizePolicy::Expanding );
	QSpacerItem * sp2 = new QSpacerItem( 10, 10, QSizePolicy::Expanding, QSizePolicy::Expanding );
	QHBoxLayout * l4 = new QHBoxLayout(0, 4, 2);
	l4->addItem( sp1 );
	l4->addWidget( ok_button );
	l4->addItem( sp2 );


	QVBoxLayout * l3 = new QVBoxLayout(this, 4, 2);
	l3->addLayout( l2 );
	l3->addLayout( l4 );

	intro->setText( 
		"<b>SMPlayer</b> (c) 2006-2007 RVM &lt;rvm@escomposlinux.org&gt;<br><br>"
		"<b>" + tr("Version: %1").arg(VERSION) + "</b><br><br>" +
        tr("Qt version: %1").arg(QT_VERSION_STR) + "<br><br>" 
		"<i>" +
		tr("This program is free software; you can redistribute it and/or modify "
	    "it under the terms of the GNU General Public License as published by "
	    "the Free Software Foundation; either version 2 of the License, or "
  	    "(at your option) any later version.") + "</i>");

	credits->setText(
		 tr("Translators:") + "<br>"
         "<ul>"
         "<li>Henrikx <i>&lt;forum.gleitz.info&gt;</i> (" + tr("German") + ")</li>"
         "<li>Sweto &lt;peter.mendel@gmail.com&gt; (" +tr("Slovak") + ")</li>"
         "<li>Giancarlo Scola &lt;giancarlo@codexcoop.it&gt; (" +tr("Italian") + ")</li>"
         "<li>Olivier g &lt;1got@caramail.com&gt; (" +tr("French") + ")</li>"
         "<li>Tim Green &lt;iamtimgreen@gmail.com&gt; (" +tr("Simplified-Chinese") + ")</li>"
         "<li>Yurkovsky Andrey &lt;anyr@tut.by&gt; (" +tr("Russian") + ")</li>"
         "<li>Charles Barcza &lt;kbarcza@blackpanther.hu&gt; (" +tr("Hungarian") + ")</li>"
         "<li>" + tr("%1 and %2 (Polish)").arg("qla &lt;qla0@vp.pl&gt;").arg("Jarek &lt;ajep9691@wp.pl&gt;") +"</li>"
         "<li>Nardog &lt;nardog@e2umail.com&gt; (" +tr("Japanese") + ")</li>"
         "<li>Wesley S. &lt;wesley@ubuntu-nl.org&gt; (" +tr("Dutch") + ")</li>"
         "<li>Motsyo Gennadi &lt;drool@altlinux.ru&gt; (" +tr("Ukrainian") + ")</li>"
         "<li>Ventura &lt;ventura.barbeiro@terra.com.br&gt; (" +tr("Brazilian Portuguese") + ")</li>"
         "<li>George Machitidze &lt;giomac@gmail.com&gt; (" +tr("Georgian") + ")</li>"
         "<li>" + QString::fromUtf8("Martin Dvořák") + " &lt;martin.dvorak@centrum.cz&gt; (" +tr("Czech") + ")</li>"
         "</ul>" +
		 tr("Logo designed by %1").arg("Charles Barcza &lt;kbarcza@blackpanther.hu&gt;")
		);

	foot->setText(
		 tr("Get updates at: %1")
         .arg("<a href=\"http://smplayer.sourceforge.net/\">http://smplayer.sourceforge.net/</a>")
		);

	adjustSize();
	setFixedSize( sizeHint() );
}

AboutDialog::~AboutDialog() {
}

